///////////////////////////////////////////////////////////////////////////////
//
//	$Id: ferret.h,v 1.14 1996/09/07 04:31:53 bcwhite Exp $
//
//	Ferret Search Engine -- class definitions
//
//	Written by:  Brian C. White
//	Copyright (c) 1996 by Verisim, Inc.  All rights reserved.
//
///////////////////////////////////////////////////////////////////////////////
//
//	Description
//	~~~~~~~~~~~
//
///////////////////////////////////////////////////////////////////////////////


#ifndef _ferret_h
#define _ferret_h






class Ferret {

public:
	 Ferret(void);
	~Ferret(void);

	enum {
		MAXWORDLENGTH	= 64,

		OPT_TINY		= 0x00000001L,
		OPT_NOSTOPPERS	= 0x00000002L,

		END_OF_FERRET_CONSTANTS
	};

	static	void	Message(void);
	static	uint	StripNonWords(char* data, uint length);
	static	uint	StripWords(char* data, uint length, char* stops, char** words);
	static	uint	StripBadLines(char* data, uint length);

	long	Options(void);
	int		SetOptionFlag(unsigned long);
	int		UnsetOptionFlag(unsigned long);

	int		OpenIndex(const char* File, int Mode=0);
	int		CloseIndex(void);
	int		FlushIndex(void);
	int		ShrinkIndex(void);
	int		CopyIndexTo(const char* File);

	char*	DBGetWords(char* Key);
	int		DBPutWords(char* Key, char* Data);
	char*	DBGetUser(char* Key);
	int		DBPutUser(char* Key, char* Data);
	int		DBDelUser(char* Key);
	char*	DBGetSummary(char* Key);
	int		DBPutSummary(char* Key, char* Data);
	int		DBDelSummary(char* Key);
	char*	DBGetTitle(char* Key);
	int		DBPutTitle(char* Key, char* Data);
	int		DBDelTitle(char* Key);

	char*	CommonWords(double Min, double Max=-1.0);
	char*	ListDocuments(void);

	ulong	DocumentTimestamp(const char* Name);
	char*	AddDocumentWords(const char* Name, const char* Words);
	int		RemoveDocumentWords(const char* Name);
	int		MoveDocumentWords(const char* OldName, const char* NewName);

	char*	QueryResults(int Result);
	int		QueryWord(char* Word);
	int		QueryNegate(int Result);
	int		QueryAnd(int Left, int Right, int Proximity=0);
	int		QueryOr(int Left, int Right);
	void	FreeQueryResult(int Match);
};


#endif
